==> risk-center-api-0.4.24-20190201.084609-3-sources.jar: cn/com/duiba/tuia/risk/center/api/dto/req/RiskSlotReviewDiffReq.java <==
package cn.com.duiba.tuia.risk.center.api.dto.req;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import java.io.Serializable;

@ApiModel
public class RiskSlotReviewDiffReq implements Serializable {

    private static final long serialVersionUID = 5961962210194869447L;

    @ApiModelProperty("查询起点")
    private Integer offset;

    @ApiModelProperty("分页长度")
    private Integer limit;

    @ApiModelProperty("广告计划ID")
    private Long advertId;

    @ApiModelProperty("差异度")
    private Integer diff;

    @ApiModelProperty("审核状态")
    private Integer reviewStatus;

    @ApiModelProperty("结束时间")
    private String startTime;

    @ApiModelProperty("开始时间")
    private String endTime;

    public Integer getOffset() {
        return offset;
    }

    public void setOffset(Integer offset) {
        this.offset = offset;
    }

    public Integer getLimit() {
        return limit;
    }

    public void setLimit(Integer limit) {
        this.limit = limit;
    }

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public Integer getReviewStatus() {
        return reviewStatus;
    }

    public void setReviewStatus(Integer reviewStatus) {
        this.reviewStatus = reviewStatus;
    }

    public String getStartTime() {
        return startTime;
    }

    public void setStartTime(String startTime) {
        this.startTime = startTime;
    }

    public String getEndTime() {
        return endTime;
    }

    public void setEndTime(String endTime) {
        this.endTime = endTime;
    }

    public Integer getDiff() {
        return diff;
    }

    public void setDiff(Integer diff) {
        this.diff = diff;
    }
}

==> risk-center-api-0.5.5-20190724.110701-6-sources.jar: cn/com/duiba/tuia/risk/center/api/dto/req/RiskSlotReviewDiffReq.java <==
package cn.com.duiba.tuia.risk.center.api.dto.req;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import java.io.Serializable;

@ApiModel
public class RiskSlotReviewDiffReq implements Serializable {

    private static final long serialVersionUID = 5961962210194869447L;

    @ApiModelProperty("查询起点")
    private Integer offset;

    @ApiModelProperty("分页长度")
    private Integer limit;

    @ApiModelProperty("广告计划ID")
    private Long advertId;

    @ApiModelProperty("差异度")
    private Integer diff;

    @ApiModelProperty("审核状态")
    private Integer reviewStatus;

    @ApiModelProperty("结束时间")
    private String startTime;

    @ApiModelProperty("开始时间")
    private String endTime;

    @ApiModelProperty("代理商")
    private String agent;

    public Integer getOffset() {
        return offset;
    }

    public void setOffset(Integer offset) {
        this.offset = offset;
    }

    public Integer getLimit() {
        return limit;
    }

    public void setLimit(Integer limit) {
        this.limit = limit;
    }

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public Integer getReviewStatus() {
        return reviewStatus;
    }

    public void setReviewStatus(Integer reviewStatus) {
        this.reviewStatus = reviewStatus;
    }

    public String getStartTime() {
        return startTime;
    }

    public void setStartTime(String startTime) {
        this.startTime = startTime;
    }

    public String getEndTime() {
        return endTime;
    }

    public void setEndTime(String endTime) {
        this.endTime = endTime;
    }

    public Integer getDiff() {
        return diff;
    }

    public void setDiff(Integer diff) {
        this.diff = diff;
    }

    public String getAgent() {
        return agent;
    }

    public void setAgent(String agent) {
        this.agent = agent;
    }
}
